@@ -58,34 +58,56 @@ UTPexExtensionMessage::~UTPexExtensionMessage() {}
 
 std::string UTPexExtensionMessage::getPayload()
 {
-  std::pair<std::string, std::string> freshPeerPair =
+  std::pair<std::pair<std::string, std::string>,
+            std::pair<std::string, std::string> > freshPeerPair =
     createCompactPeerListAndFlag(freshPeers_);
-  std::pair<std::string, std::string> droppedPeerPair =
+  std::pair<std::pair<std::string, std::string>,
+            std::pair<std::string, std::string> > droppedPeerPair =
     createCompactPeerListAndFlag(droppedPeers_);
 
   Dict dict;
-  dict.put("added", freshPeerPair.first);
-  dict.put("added.f", freshPeerPair.second);
-  dict.put("dropped", droppedPeerPair.first);
+  if(!freshPeerPair.first.first.empty()) {
+    dict.put("added", freshPeerPair.first.first);
+    dict.put("added.f", freshPeerPair.first.second);
+  }
+  if(!droppedPeerPair.first.first.empty()) {
+    dict.put("dropped", droppedPeerPair.first.first);
+  }
+  if(!freshPeerPair.second.first.empty()) {
+    dict.put("added6", freshPeerPair.second.first);
+    dict.put("added6.f", freshPeerPair.second.second);
+  }
+  if(!droppedPeerPair.second.first.empty()) {
+    dict.put("dropped6", droppedPeerPair.second.first);
+  }
+
   return bencode2::encode(&dict);
 }
 
-std::pair<std::string, std::string>
+std::pair<std::pair<std::string, std::string>,
+          std::pair<std::string, std::string> >
 UTPexExtensionMessage::createCompactPeerListAndFlag
 (const std::vector<SharedHandle<Peer> >& peers)
 {
   std::string addrstring;
   std::string flagstring;
+  std::string addrstring6;
+  std::string flagstring6;
   for(std::vector<SharedHandle<Peer> >::const_iterator itr = peers.begin(),
         eoi = peers.end(); itr != eoi; ++itr) {
-    unsigned char compact[6];
-    if(bittorrent::createcompact
-       (compact, (*itr)->getIPAddress(), (*itr)->getPort())) {
-      addrstring.append(&compact[0], &compact[6]);
-      flagstring += (*itr)->isSeeder() ? "2" : "0";
+    unsigned char compact[COMPACT_LEN_IPV6];
+    int compactlen = bittorrent::packcompact
+      (compact, (*itr)->getIPAddress(), (*itr)->getPort());
+    if(compactlen == COMPACT_LEN_IPV4) {
+      addrstring.append(&compact[0], &compact[compactlen]);
+      flagstring += (*itr)->isSeeder() ? 0x02 : 0x00;
+    } else if(compactlen == COMPACT_LEN_IPV6) {
+      addrstring6.append(&compact[0], &compact[compactlen]);
+      flagstring6 += (*itr)->isSeeder() ? 0x02 : 0x00;
     }
   }
-  return std::pair<std::string, std::string>(addrstring, flagstring);
+  return std::make_pair(std::make_pair(addrstring, flagstring),
+                        std::make_pair(addrstring6, flagstring6));
 }
 
 std::string UTPexExtensionMessage::toString() const
@@ -97,6 +119,7 @@ std::string UTPexExtensionMessage::toString() const
 void UTPexExtensionMessage::doReceivedAction()
 {
   peerStorage_->addPeer(freshPeers_);
+  peerStorage_->addPeer(droppedPeers_);
 }
 
 bool UTPexExtensionMessage::addFreshPeer(const SharedHandle<Peer>& peer)
@@ -162,11 +185,23 @@ UTPexExtensionMessage::create(const unsigned char* data, size_t len)
   if(dict) {
     const String* added = asString(dict->get("added"));
     if(added) {
-      bittorrent::extractPeer(added, std::back_inserter(msg->freshPeers_));
+      bittorrent::extractPeer
+        (added, AF_INET,  std::back_inserter(msg->freshPeers_));
     }
     const String* dropped = asString(dict->get("dropped"));
     if(dropped) {
-      bittorrent::extractPeer(dropped, std::back_inserter(msg->droppedPeers_));
+      bittorrent::extractPeer
+        (dropped, AF_INET, std::back_inserter(msg->droppedPeers_));
+    }
+    const String* added6 = asString(dict->get("added6"));
+    if(added6) {
+      bittorrent::extractPeer
+        (added6, AF_INET6, std::back_inserter(msg->freshPeers_));
+    }
+    const String* dropped6 = asString(dict->get("dropped6"));
+    if(dropped6) {
+      bittorrent::extractPeer
+        (dropped6, AF_INET6, std::back_inserter(msg->droppedPeers_));
     }
   }
   return msg;
