@@ -52,7 +52,10 @@
     "                              remaining URLs are used for backup. If less than\n" \
     "                              N URLs are given, those URLs are used more than\n" \
     "                              once so that N connections total are made\n" \
-    "                              simultaneously. Please see -j option too.\n" \
+    "                              simultaneously. The number of connections to the\n" \
+    "                              same host is restricted by\n"        \
+    "                              --max-connection-per-server option. Please see -j\n" \
+    "                              and --min-split-size option too.\n"  \
     "                              Please note that in Metalink download, this\n" \
     "                              option has no effect and use -C option instead.")
 #define TEXT_RETRY_WAIT                                                 \
@@ -144,10 +147,9 @@
     "                              allocating files.\n"                 \
     "                              Turn off if you encounter any error")
 #define TEXT_ALLOW_OVERWRITE                                            \
-  _(" --allow-overwrite=true|false If false is given, and a file already exists but\n" \
-    "                              the corresponding control file (filename.aria2)\n" \
-    "                              doesn't exist, then aria2 will not re-download\n" \
-    "                              the file. See also --auto-file-renaming option.")
+  _(" --allow-overwrite=true|false Restart download from scratch if the\n" \
+    "                              corresponding control file doesn't exist.  See\n" \
+    "                              also --auto-file-renaming option.")
 #define TEXT_ALLOW_PIECE_LENGTH_CHANGE                                  \
   _(" --allow-piece-length-change=true|false If false is given, aria2 aborts download\n" \
     "                              when a piece length is different from one in\n" \
@@ -295,18 +297,18 @@
 #define TEXT_ENABLE_PEER_EXCHANGE                                       \
   _(" --enable-peer-exchange[=true|false] Enable Peer Exchange extension.")
 #define TEXT_ENABLE_DHT                                         \
-  _(" --enable-dht[=true|false]    Enable DHT functionality.")
+  _(" --enable-dht[=true|false]    Enable IPv4 DHT functionality.")
 #define TEXT_DHT_LISTEN_PORT                                            \
-  _(" --dht-listen-port=PORT...    Set UDP listening port for DHT.\n"   \
-    "                              Multiple ports can be specified by using ',',\n" \
-    "                              for example: \"6881,6885\". You can also use '-'\n" \
-    "                              to specify a range: \"6881-6999\". ',' and '-' can\n" \
-    "                              be used together.")
+  _(" --dht-listen-port=PORT...    Set UDP listening port for both IPv4 and IPv6\n"   \
+    "                              DHT. Multiple ports can be specified by using\n" \
+    "                              ',', for example: \"6881,6885\". You can also\n" \
+    "                              use '-' to specify a range: \"6881-6999\". ','\n" \
+    "                              and '-' can be used together.")
 #define TEXT_DHT_ENTRY_POINT                                            \
-  _(" --dht-entry-point=HOST:PORT  Set host and port as an entry point to DHT\n" \
+  _(" --dht-entry-point=HOST:PORT  Set host and port as an entry point to IPv4 DHT\n" \
     "                              network.")
 #define TEXT_DHT_FILE_PATH                                              \
-  _(" --dht-file-path=PATH         Change the DHT routing table file to PATH.")
+  _(" --dht-file-path=PATH         Change the IPv4 DHT routing table file to PATH.")
 #define TEXT_BT_MIN_CRYPTO_LEVEL                                        \
   _(" --bt-min-crypto-level=plain|arc4 Set minimum level of encryption method.\n" \
     "                              If several encryption methods are provided by a\n" \
@@ -481,7 +483,8 @@
   _(" --check-certificate[=true|false] Verify the peer using certificates specified\n" \
     "                              in --ca-certificate option.")
 #define TEXT_NO_PROXY                                                   \
-  _(" --no-proxy=DOMAINS           Specify comma separated hostnames or domains where\n" \
+  _(" --no-proxy=DOMAINS           Specify comma separated hostnames, domains or\n" \
+    "                              network address with or without CIDR block where\n" \
     "                              proxy should not be used.")
 #define TEXT_USE_HEAD                                                   \
   _(" --use-head[=true|false]      Use HEAD method for the first request to the HTTP\n" \
@@ -547,6 +550,11 @@
   _(" --on-download-start=COMMAND  Set the command to be executed when download\n" \
     "                              starts up. COMMAND must take just one argument and\n" \
     "                              GID is passed to COMMAND as a first argument.")
+#define TEXT_ON_DOWNLOAD_PAUSE                                          \
+  _(" --on-download-pause=COMMAND  Set the command to be executed when download\n" \
+    "                              is paused.\n"\
+    "                              See --on-download-start option for the\n" \
+    "                              requirement of COMMAND.")
 #define TEXT_ON_DOWNLOAD_ERROR                                          \
   _(" --on-download-error=COMMAND  Set the command to be executed when download\n" \
     "                              aborts due to error.\n"              \
@@ -609,3 +617,127 @@
 #define TEXT_HUMAN_READABLE                     \
   _(" --human-readable[=true|false] Print sizes and speed in human readable format\n" \
     "                              (e.g., 1.2Ki, 3.4Mi) in the console readout.")
+#define TEXT_BT_ENABLE_LPD                      \
+  _(" --bt-enable-lpd[=true|false] Enable Local Peer Discovery.")
+#define TEXT_BT_LPD_INTERFACE                                           \
+  _(" --bt-lpd-interface=INTERFACE Use given interface for Local Peer Discovery. If\n" \
+    "                              this option is not specified, the default\n" \
+    "                              interface is chosen. You can specify interface\n" \
+    "                              name and IP address.")
+#define TEXT_REUSE_URI                          \
+  _(" --reuse-uri[=true|false]     Reuse already used URIs if no unused URIs are\n" \
+    "                              left.")
+#define TEXT_ALL_PROXY_USER                                             \
+  _(" --all-proxy-user=USER        Set user for --all-proxy option.")
+#define TEXT_ALL_PROXY_PASSWD                                           \
+  _(" --all-proxy-passwd=PASSWD    Set password for --all-proxy option.")
+#define TEXT_HTTP_PROXY_USER                                            \
+  _(" --http-proxy-user=USER       Set user for --http-proxy option.")
+#define TEXT_HTTP_PROXY_PASSWD                                          \
+  _(" --http-proxy-passwd=PASSWD   Set password for --http-proxy option.")
+#define TEXT_HTTPS_PROXY_USER                                           \
+  _(" --https-proxy-user=USER      Set user for --https-proxy option.")
+#define TEXT_HTTPS_PROXY_PASSWD                                         \
+  _(" --https-proxy-passwd=PASSWD  Set password for --https-proxy option.")
+#define TEXT_FTP_PROXY_USER                                             \
+  _(" --ftp-proxy-user=USER        Set user for --ftp-proxy option.")
+#define TEXT_FTP_PROXY_PASSWD                                           \
+  _(" --ftp-proxy-passwd=PASSWD    Set password for --ftp-proxy option.")
+#define TEXT_REMOVE_CONTROL_FILE                \
+  _(" --remove-control-file[=true|false] Remove control file before download. Using\n" \
+    "                              with --allow-overwrite=true, download always\n" \
+    "                              starts from scratch. This will be useful for\n" \
+    "                              users behind proxy server which disables resume.")
+#define TEXT_ALWAYS_RESUME                      \
+  _(" --always-resume[=true|false] Always resume download. If true is given, aria2\n" \
+    "                              always tries to resume download and if resume is\n" \
+    "                              not possible, aborts download. If false is given,\n" \
+    "                              when all given URIs do not support resume or\n" \
+    "                              aria2 encounters N URIs which does not support\n" \
+    "                              resume (N is the value specified using\n"   \
+    "                              --max-resume-failure-tries option), aria2\n" \
+    "                              downloads file from scratch.\n"       \
+    "                              See --max-resume-failure-tries option.")
+#define TEXT_MAX_RESUME_FAILURE_TRIES                                   \
+  _(" --max-resume-failure-tries=N When used with --always-resume=false, aria2\n" \
+    "                              downloads file from scratch when aria2 detects N\n" \
+    "                              number of URIs that does not support resume. If N\n" \
+    "                              is 0, aria2 downloads file from scratch when all\n" \
+    "                              given URIs do not support resume.\n" \
+    "                              See --always-resume option.")
+#define TEXT_BT_TRACKER_TIMEOUT                                 \
+  _(" --bt-tracker-timeout=SEC     Set timeout in seconds.")
+#define TEXT_BT_TRACKER_CONNECT_TIMEOUT                                 \
+  _(" --bt-tracker-connect-timeout=SEC Set the connect timeout in seconds to\n" \
+    "                              establish connection to tracker. After the\n" \
+    "                              connection is established, this option makes no\n" \
+    "                              effect and --bt-tracker-timeout option is used\n" \
+    "                              instead.")
+#define TEXT_DHT_MESSAGE_TIMEOUT                \
+  _(" --dht-message-timeout=SEC    Set timeout in seconds.")
+#define TEXT_HTTP_ACCEPT_GZIP                   \
+  _(" --http-accept-gzip[=true|false] Send 'Accept: deflate, gzip' request header\n" \
+    "                              and inflate response if remote server responds\n" \
+    "                              with 'Content-Encoding: gzip' or\n"  \
+    "                              'Content-Encoding: deflate'.")
+#define TEXT_SAVE_SESSION                       \
+  _(" --save-session=FILE          Save error/unfinished downloads to FILE on exit.\n" \
+    "                              You can pass this output file to aria2c with -i\n" \
+    "                              option on restart. Please note that downloads\n" \
+    "                              added by aria2.addTorrent and aria2.addMetalink\n" \
+    "                              XML-RPC method are not saved.")
+#define TEXT_MAX_CONNECTION_PER_SERVER          \
+  _(" --max-connection-per-server=NUM The maximum number of connections to one server\n"\
+    "                              for each download.")
+#define TEXT_MIN_SPLIT_SIZE                     \
+  _(" --min-split-size=SIZE        aria2 does not split less than 2*SIZE byte range.\n" \
+    "                              For example, let's consider downloading 20MiB\n" \
+    "                              file. If SIZE is 10M, aria2 can split file into 2\n" \
+    "                              range [0-10MiB) and [10MiB-20MiB) and download it\n" \
+    "                              using 2 sources(if --split >= 2, of course).\n" \
+    "                              If SIZE is 15M, since 2*15M > 20MiB, aria2 does\n" \
+    "                              not split file and download it using 1 source.\n" \
+    "                              You can append K or M(1K = 1024, 1M = 1024K).")
+#define TEXT_CONDITIONAL_GET                    \
+  _(" --conditional-get[=true|false] Download file only when the local file is older\n" \
+    "                              than remote file. Currently, this function has\n" \
+    "                              many limitations. See man page for details.")
+#define TEXT_ON_BT_DOWNLOAD_COMPLETE            \
+  _(" --on-bt-download-complete=COMMAND For BitTorrent, a command specified in\n" \
+    "                              --on-download-complete is called when download\n" \
+    "                              completes and seeding is over. On the other hand,\n" \
+    "                              this option sets the command to be executed when\n" \
+    "                              download completes but before seeding.\n" \
+    "                              See --on-download-start option for the\n" \
+    "                              requirement of COMMAND.")
+#define TEXT_ENABLE_ASYNC_DNS6                  \
+  _(" --enable-async-dns6[=true|false] Enable IPv6 name resolution in asynchronous\n" \
+    "                              DNS resolver. This option will be ignored when\n" \
+    "                              --async-dns=false.")
+#define TEXT_ENABLE_DHT6                        \
+  _(" --enable-dht6[=true|false]   Enable IPv6 DHT functionality.\n" \
+    "                              Use --dht-listen-port option to specify port\n" \
+    "                              number to listen on. See also --dht-listen-addr6\n" \
+    "                              option.")
+#define TEXT_DHT_LISTEN_ADDR6                   \
+  _(" --dht-listen-addr6=ADDR      Specify address to bind socket for IPv6 DHT. \n" \
+    "                              It should be a global unicast IPv6 address of the\n" \
+    "                              host.")
+#define TEXT_DHT_ENTRY_POINT6                   \
+  _(" --dht-entry-point6=HOST:PORT Set host and port as an entry point to IPv6 DHT\n" \
+    "                              network.")
+#define TEXT_DHT_FILE_PATH6                     \
+  _(" --dht-file-path6=PATH        Change the IPv6 DHT routing table file to PATH.")
+#define TEXT_BT_TRACKER                                                 \
+  _(" --bt-tracker=URI[,...]       Comma separated list of additional BitTorrent\n" \
+    "                              tracker's announce URI. These URIs are not\n" \
+    "                              affected by --bt-exclude-tracker option because\n" \
+    "                              they are added after URIs in --bt-exclude-tracker\n" \
+    "                              option are removed.")
+#define TEXT_BT_EXCLUDE_TRACKER                                         \
+  _(" --bt-exclude-tracker=URI[,...] Comma separated list of BitTorrent tracker's\n" \
+    "                              announce URI to remove. You can use special value\n" \
+    "                              '*' which matches all URIs, thus removes all\n" \
+    "                              announce URIs. When specifying '*' in shell\n" \
+    "                              command-line, don't forget to escape or quote it.\n" \
+    "                              See also --bt-tracker option.")
